==> nextcloud-app-mail-2.2.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/id.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Penting",
    "Work" : "Kantor",
    "Personal" : "Pribadi",
    "Later" : "Nanti",
    "Mail" : "Email",
    "Name" : "Nama",
    "Password" : "Kata kunci",
    "None" : "Tidak ada",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Kata sandi SMTP",
    "Connecting" : "Menyambungkan",
    "Save" : "Simpan",
    "Connect" : "Sambungkan",
    "Signature" : "Tanda",
    "Email address" : "Alamat email",
    "Cancel" : "Membatalkan",
    "Add mail account" : "Tambahkan akun email",
    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
    "Subject" : "Subjek",
    "Upload attachment" : "Unggah lampiran",
    "Sending …" : "Mengirim ...",
    "Go back" : "Kembali",
    "Retry" : "Ulangi",
    "Message sent!" : "Kirim pesan!",
    "Send" : "Kirim",
    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
    "Favorite" : "Favorit",
    "Read" : "Baca",
    "Unselect" : "Batal pilih",
    "Select" : "Pilih",
    "Edit tags" : "Sunting label",
    "Move" : "Pindah",
    "Create event" : "Buat acara",
    "Forward" : "Teruskan",
    "All day" : "Sepanjang hari",
    "Create" : "Buat",
    "Comment" : "Komentar",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Choose" : "Pilih",
    "Other" : "Lainnya",
    "Reply" : "Balas",
    "Import into calendar" : "Impor ke kalender",
    "Download attachment" : "Unduh lampiran",
    "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
    "Quota" : "Kuota",
    "Saving" : "Menyimpan",
    "Remove account" : "Hapus akun",
    "Mark all as read" : "Tandai semua telah dibaca",
    "Edit name" : "Edit nama",
    "Clear cache" : "Bersihkan cache",
    "New message" : "Pesan baru",
    "Message" : "Pesan",
    "Delete" : "Hapus",
    "Add" : "Masukkan",
    "Tags" : "Tag",
    "Clear" : "Bersihkan",
    "Search" : "Cari",
    "Date" : "Date",
    "Disabled" : "Dinonaktifkan",
    "Enabled" : "Diaktifkan",
    "Tag already exists" : "Tag sudah ada",
    "Mark as read" : "tandai sudah dibaca",
    "Remove" : "Buang",
    "(organizer)" : "(penyelenggara)",
    "Untitled event" : "Acara tanpa judul",
    "Reset" : "Setel ulang",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "General" : "Umum",
    "User" : "Pengguna",
    "Host" : "Host",
    "Port" : "Port",
    "Account connected" : "Akun terhubung",
    "Keyboard shortcut" : "Pintasan keyboard",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Refresh" : "Segarkan",
    "Connect your mail account" : "Hubungkan akun email Anda",
    "All" : "Semua",
    "Archive" : "Arsip",
    "Drafts" : "Konsep",
    "Favorites" : "Disukai",
    "All inboxes" : "Semua kotak masuk",
    "Inbox" : "Kotak masuk",
    "Junk" : "Sampah",
    "Sent" : "Kirim",
    "Trash" : "Tempat sampah",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Error loading message" : "Terjadi kesalahan saat memuat pesan",
    "Forwarding to %s" : "Teruskan ke %s",
    "Redirect" : "Mengalihkan",
    "Continue to %s" : "Lanjutkan ke %s"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-3.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/id.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Penting",
    "Work" : "Kantor",
    "Personal" : "Pribadi",
    "Later" : "Nanti",
    "Mail" : "Email",
    "Name" : "Nama",
    "Password" : "Kata kunci",
    "None" : "Tidak ada",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Kata sandi SMTP",
    "Connecting" : "Menyambungkan",
    "Save" : "Simpan",
    "Connect" : "Sambungkan",
    "Password required" : "Kata sandi diperlukan",
    "Signature" : "Tanda",
    "Email address" : "Alamat email",
    "Cancel" : "Membatalkan",
    "Add mail account" : "Tambahkan akun email",
    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
    "Subject" : "Subjek",
    "Upload attachment" : "Unggah lampiran",
    "Add link" : "Tambah tautan",
    "Send" : "Kirim",
    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
    "Favorite" : "Favorit",
    "Read" : "Baca",
    "Unselect" : "Batal pilih",
    "Select" : "Pilih",
    "Edit tags" : "Sunting label",
    "Create event" : "Buat acara",
    "Forward" : "Teruskan",
    "All day" : "Sepanjang hari",
    "Create" : "Buat",
    "Comment" : "Komentar",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Choose" : "Pilih",
    "Other" : "Lainnya",
    "Reply" : "Balas",
    "Import into calendar" : "Impor ke kalender",
    "Download attachment" : "Unduh lampiran",
    "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
    "Move" : "Pindah",
    "Quota" : "Kuota",
    "Saving" : "Menyimpan",
    "Remove account" : "Hapus akun",
    "Mark all as read" : "Tandai semua telah dibaca",
    "Edit name" : "Edit nama",
    "Clear cache" : "Bersihkan cache",
    "New message" : "Pesan baru",
    "Go back" : "Kembali",
    "Retry" : "Ulangi",
    "Sending …" : "Mengirim ...",
    "Message" : "Pesan",
    "Delete" : "Hapus",
    "Add" : "Masukkan",
    "Tags" : "Tag",
    "Clear" : "Bersihkan",
    "Search" : "Cari",
    "Date" : "Date",
    "Disabled" : "Dinonaktifkan",
    "Enabled" : "Diaktifkan",
    "Tag already exists" : "Tag sudah ada",
    "Mark as read" : "tandai sudah dibaca",
    "Remove" : "Buang",
    "(organizer)" : "(penyelenggara)",
    "Untitled event" : "Acara tanpa judul",
    "Reset" : "Setel ulang",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "General" : "Umum",
    "User" : "Pengguna",
    "Host" : "Host",
    "Port" : "Port",
    "Valid until" : "Berlaku sampai",
    "Certificate" : "Sertifikat",
    "Back" : "Kembali",
    "Keyboard shortcut" : "Pintasan keyboard",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Archive" : "Arsip",
    "Refresh" : "Segarkan",
    "Account connected" : "Akun terhubung",
    "Connect your mail account" : "Hubungkan akun email Anda",
    "All" : "Semua",
    "Drafts" : "Konsep",
    "Favorites" : "Disukai",
    "All inboxes" : "Semua kotak masuk",
    "Inbox" : "Kotak masuk",
    "Junk" : "Sampah",
    "Sent" : "Kirim",
    "Trash" : "Tempat sampah",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Error loading message" : "Terjadi kesalahan saat memuat pesan",
    "Forwarding to %s" : "Teruskan ke %s",
    "Redirect" : "Mengalihkan",
    "Continue to %s" : "Lanjutkan ke %s"
},
"nplurals=1; plural=0;");
